[![Downloads][pepy-downloads-badge]][pepy-downloads-link]
[![PyPI][pypi-latest-release-badge]][pypi-latest-release-link]
[![PyPI versions][pypi-pyversion-badge]][pypi-pyversion-link]
[![GitHub Discussion][github-discussions-badge]][github-discussions-link]
[![Code style: black][black-badge]][black-link]
[![Documentation status][readthedocs-badge]][readthedocs-link]
[![Tests][github-tests-badge]][github-tests-link]

# nornir-salt

Collection of Nornir plugins for [SALTSTACK Nornir Proxy Minion modules](https://github.com/dmulyalin/salt-nornir).

All plugins and functions can be used with Nornir directly unless stated otherwise.

Refer to [documentation](https://nornir-salt.readthedocs.io/en/latest/) for additional information.

# Contributing

Issues, bug reports and feature requests are welcomed.

[github-discussions-link]:     https://github.com/dmulyalin/nornir-salt/discussions
[github-discussions-badge]:    https://img.shields.io/static/v1?label=Discussions&message=Ask&color=blue&logo=github
[black-badge]:                 https://img.shields.io/badge/code%20style-black-000000.svg
[black-link]:                  https://github.com/psf/black
[pypi-pyversion-link]:         https://pypi.python.org/pypi/nornir-salt/
[pypi-pyversion-badge]:        https://img.shields.io/pypi/pyversions/nornir-salt.svg
[pepy-downloads-link]:         https://pepy.tech/project/nornir-salt
[pepy-downloads-badge]:        https://pepy.tech/badge/nornir-salt
[readthedocs-link]:            http://nornir-salt.readthedocs.io/?badge=latest
[readthedocs-badge]:           https://readthedocs.org/projects/nornir-salt/badge/?version=latest
[github-tests-badge]:          https://github.com/dmulyalin/nornir-salt/actions/workflows/main.yml/badge.svg?branch=master
[github-tests-link]:           https://github.com/dmulyalin/nornir-salt/actions
[pypi-latest-release-badge]:   https://img.shields.io/pypi/v/nornir-salt.svg
[pypi-latest-release-link]:    https://pypi.python.org/pypi/nornir-salt
